@@ -1,5 +1,6 @@
-from networks import MSDNet, UNet
+from networks.MSDNet import MSDNet
+from networks.UNet import UNet
 from .dataset import CustomImageDataset, CustomGreyImageDataset
 from .metric import psnr, psnr_np
 from .train import train_loop, test_loop, valid_loop
-from .utils import count_parameters
\ No newline at end of file
+from .utils import count_parameters
